<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\HiringRequest;
use App\Http\Resources\HiringResource;
use App\Models\Hiring;
use Illuminate\Http\JsonResponse;

class HiringController extends Controller
{
    protected array $relations = [
        "worker"
    ];

    /**
     * Display a listing of the hirings.
     */
    public function index(): JsonResponse {
        $hirings = $this->paginateOrGet(Hiring::filter()->latest());

        return $this->respondWithResourceCollection(
            HiringResource::collection($hirings)
        );
    }

    /**
     * Store a newly created hiring in storage.
     */
    public function store(HiringRequest $request): JsonResponse {
        $hiring = Hiring::create($request->validated());

        return $this->respondCreated(
            new HiringResource($hiring),
            "Hiring created successfully!"
        );
    }

    /**
     * Display the specified hiring.
     */
    public function show(Hiring $hiring): JsonResponse {
        $hiring->loadMissing($this->relations);

        return $this->respondWithResource(new HiringResource($hiring));
    }

    /**
     * Update the specified hiring in storage.
     */
    public function update(HiringRequest $request, Hiring $hiring): JsonResponse {
        $hiring->update($request->validated());

        return $this->respondUpdated(
            new HiringResource($hiring),
            "Hiring updated successfully!"
        );
    }

    /**
     * Remove the specified hiring from storage.
     */
    public function destroy(Hiring $hiring): JsonResponse {
        $hiring->delete();

        return $this->respondSuccess("Hiring deleted successfully!");
    }
}
