<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\LanguageRequest;
use App\Http\Resources\LanguageResource;
use App\Models\Language;
use Illuminate\Http\JsonResponse;

class LanguageController extends Controller
{
    /**
     * Display a listing of the languages.
     */
    public function index(): JsonResponse {
        $languages = $this->paginateOrGet(Language::latest());

        return $this->respondWithResourceCollection(
            LanguageResource::collection($languages)
        );
    }

    /**
     * Store a newly created language in storage.
     */
    public function store(LanguageRequest $request): JsonResponse {
        $language = Language::create($request->validated());

        return $this->respondCreated(
            new LanguageResource($language),
            "Language created successfully!"
        );
    }

    /**
     * Display the specified language.
     */
    public function show(Language $language): JsonResponse {
        return $this->respondWithResource(new LanguageResource($language));
    }

    /**
     * Update the specified language in storage.
     */
    public function update(LanguageRequest $request, Language $language): JsonResponse {
        $language->update($request->validated());

        return $this->respondUpdated(
            new LanguageResource($language),
            "Language updated successfully!"
        );
    }

    /**
     * Remove the specified language from storage.
     */
    public function destroy(Language $language): JsonResponse {
        $language->delete();

        return $this->respondSuccess("Language deleted successfully!");
    }
}
