<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\PartnershipRequest;
use App\Http\Resources\PartnershipResource;
use App\Models\Partnership;
use Illuminate\Http\JsonResponse;

class PartnershipController extends Controller
{
    protected array $relations = [
        "agency"
    ];

    /**
     * Display a listing of the partnerships.
     */
    public function index(): JsonResponse {
        $partnerships = $this->paginateOrGet(Partnership::filter()->latest());

        return $this->respondWithResourceCollection(
            PartnershipResource::collection($partnerships)
        );
    }

    /**
     * Store a newly created partnership in storage.
     */
    public function store(PartnershipRequest $request): JsonResponse {
        $partnership = Partnership::create($request->validated());

        return $this->respondCreated(
            new PartnershipResource($partnership),
            "Partnership created successfully!"
        );
    }

    /**
     * Display the specified partnership.
     */
    public function show(Partnership $partnership): JsonResponse {
        $partnership->loadMissing($this->relations);

        return $this->respondWithResource(new PartnershipResource($partnership));
    }

    /**
     * Update the specified partnership in storage.
     */
    public function update(PartnershipRequest $request, Partnership $partnership): JsonResponse {
        $partnership->update($request->validated());

        return $this->respondUpdated(
            new PartnershipResource($partnership),
            "Partnership updated successfully!"
        );
    }

    /**
     * Remove the specified partnership from storage.
     */
    public function destroy(Partnership $partnership): JsonResponse {
        $partnership->delete();

        return $this->respondSuccess("Partnership deleted successfully!");
    }
}
