<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\RatingRequest;
use App\Http\Resources\RatingResource;
use App\Models\Rating;
use Illuminate\Http\JsonResponse;

class RatingController extends Controller
{
    protected array $relations = [
        "ratedBy", "ratedTo", "job"
    ];

    /**
     * Display a listing of the ratings.
     */
    public function index(): JsonResponse {
        $ratings = $this->paginateOrGet(Rating::filter()->latest());

        return $this->respondWithResourceCollection(
            RatingResource::collection($ratings)
        );
    }

    /**
     * Store a newly created rating in storage.
     */
    public function store(RatingRequest $request): JsonResponse {
        $rating = Rating::create($request->validated());

        return $this->respondCreated(
            new RatingResource($rating),
            "Worker type created successfully!"
        );
    }

    /**
     * Display the specified rating.
     */
    public function show(Rating $rating): JsonResponse {
        $rating->loadMissing($this->relations);

        return $this->respondWithResource(new RatingResource($rating));
    }

    /**
     * Update the specified rating in storage.
     */
    public function update(RatingRequest $request, Rating $rating): JsonResponse {
        $rating->update($request->validated());

        return $this->respondUpdated(
            new RatingResource($rating),
            "Worker type updated successfully!"
        );
    }

    /**
     * Remove the specified rating from storage.
     */
    public function destroy(Rating $rating): JsonResponse {
        $rating->delete();

        return $this->respondSuccess("Worker type deleted successfully!");
    }
}
