<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\SkillRequest;
use App\Http\Resources\SkillResource;
use App\Models\Skill;
use Illuminate\Http\JsonResponse;

class SkillController extends Controller
{
    protected array $fileFieldNames = ['icon'];

    protected array $fileFolderPaths = ['icons'];

    protected array $relations = [
        "workTypes"
    ];

    /**
     * Display a listing of the skills.
     */
    public function index(): JsonResponse {
        $skills = $this->paginateOrGet(Skill::filter()->latest());

        return $this->respondWithResourceCollection(
            SkillResource::collection($skills)
        );
    }

    /**
     * Store a newly created skill in storage.
     */
    public function store(SkillRequest $request): JsonResponse {
        $skill = new Skill($request->validated());
        $this->storeFiles($request, $skill);
        $skill->save();

        return $this->respondCreated(
            new SkillResource($skill),
            "Skill created successfully!"
        );
    }

    /**
     * Display the specified skill.
     */
    public function show(Skill $skill): JsonResponse {
        $skill->loadMissing($this->relations);

        return $this->respondWithResource(new SkillResource($skill));
    }

    /**
     * Update the specified skill in storage.
     */
    public function update(SkillRequest $request, Skill $skill): JsonResponse {
        $skill->fill($request->validated());
        $this->updateFiles($request, $skill);
        $skill->update();

        return $this->respondUpdated(
            new SkillResource($skill),
            "Skill updated successfully!"
        );
    }

    /**
     * Remove the specified skill from storage.
     */
    public function destroy(Skill $skill): JsonResponse {
        $this->deleteFiles($skill);
        $skill->delete();

        return $this->respondSuccess("Skill deleted successfully!");
    }
}
