<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\WorkHourRequest;
use App\Http\Resources\WorkHourResource;
use App\Models\WorkHour;
use Illuminate\Http\JsonResponse;

class WorkHourController extends Controller
{
    /**
     * Display a listing of the work hours.
     */
    public function index(): JsonResponse {
        $workHours = $this->paginateOrGet(WorkHour::latest());

        return $this->respondWithResourceCollection(
            WorkHourResource::collection($workHours)
        );
    }

    /**
     * Store a newly created work hour in storage.
     */
    public function store(WorkHourRequest $request): JsonResponse {
        $workHour = WorkHour::create($request->validated());

        return $this->respondCreated(
            new WorkHourResource($workHour),
            "Work hour created successfully!"
        );
    }

    /**
     * Display the specified work hour.
     */
    public function show(WorkHour $workHour): JsonResponse {
        return $this->respondWithResource(new WorkHourResource($workHour));
    }

    /**
     * Update the specified work hour in storage.
     */
    public function update(WorkHourRequest $request, WorkHour $workHour): JsonResponse {
        $workHour->update($request->validated());

        return $this->respondUpdated(
            new WorkHourResource($workHour),
            "Work hour updated successfully!"
        );
    }

    /**
     * Remove the specified work hour from storage.
     */
    public function destroy(WorkHour $workHour): JsonResponse {
        $workHour->delete();

        return $this->respondSuccess("Work hour deleted successfully!");
    }
}
