<?php

namespace App\Http\Controllers\Api\V1;

use App\Http\Controllers\Controller;
use App\Http\Requests\WorkTypeRequest;
use App\Http\Resources\WorkTypeResource;
use App\Models\WorkType;
use Illuminate\Http\JsonResponse;

class WorkTypeController extends Controller
{
    protected array $relations = [
        "skills"
    ];

    /**
     * Display a listing of the workTypes.
     */
    public function index(): JsonResponse {
        $workTypes = $this->paginateOrGet(WorkType::filter()->latest());

        return $this->respondWithResourceCollection(
            WorkTypeResource::collection($workTypes)
        );
    }

    /**
     * Store a newly created workType in storage.
     */
    public function store(WorkTypeRequest $request): JsonResponse {
        $workType = WorkType::create($request->validated());

        // associate provided skills with workType if not empty
        if ($request->filled("skills")) {
            $workType->skills()->attach($request->validated('skills'));
        }

        return $this->respondCreated(
            new WorkTypeResource($workType),
            "Worker type created successfully!"
        );
    }

    /**
     * Display the specified workType.
     */
    public function show(WorkType $workType): JsonResponse {
        $workType->loadMissing($this->relations);

        return $this->respondWithResource(new WorkTypeResource($workType));
    }

    /**
     * Update the specified workType in storage.
     */
    public function update(WorkTypeRequest $request, WorkType $workType): JsonResponse {
        $workType->update($request->validated());

        // sync provided skills with workType if not empty
        if ($request->filled("skills")) {
            $workType->skills()->sync($request->validated('skills'));
        }

        return $this->respondUpdated(
            new WorkTypeResource($workType),
            "Worker type updated successfully!"
        );
    }

    /**
     * Remove the specified workType from storage.
     */
    public function destroy(WorkType $workType): JsonResponse {
        $workType->delete();

        return $this->respondSuccess("Worker type deleted successfully!");
    }
}
