<?php

namespace App\Http\Controllers;

use App\Http\Traits\CanManageFile;
use App\Http\Traits\Response\HasApiResponse;
use Exception;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Http\JsonResponse;
use Illuminate\Support\Facades\DB;

abstract class Controller
{
    use HasApiResponse, CanManageFile;

    protected array $fileFieldNames = [];

    protected array $fileFolderPaths = [];

    protected array $relations = [];

    protected function paginateOrGet(Builder $query) {
        $page = request()->query('page');
        $perPage = request()->query('perPage', 15); // Default perPage to 15 if not provided

        return $query->when($page,
            fn(Builder $q) => $q->paginate($perPage),
            fn(Builder $q) => $q->get()
        );
    }

    protected function transactional(callable $callback): Model|JsonResponse|null {
        DB::beginTransaction();
        try {
            // Execute the callback
            $result = $callback();

            DB::commit(); // commit the transaction
            return $result; // return the result of the callback
        } catch (Exception $e) {
            DB::rollBack(); // rollback the transaction

            // log the error
            \Log::error($e->getMessage());

            return $this->respondError(
                "Action failed: ".$e->getMessage(), $e
            );
        }
    }
}
