<?php

namespace App\Http\Requests;

use App\Enums\JobType;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class JobRequest extends FormRequest
{
    public function rules(): array {
        $rules = [
            'user_id' => ['required', 'exists:users,id'],
            'work_type_id' => ['required', 'exists:work_types,id'],
            'work_hour_id' => ['required', 'exists:work_hours,id'],

            'title' => ['required', 'string', 'max:100'],
            'description' => ['required', 'string'],
            'location' => ['required', 'string', 'max:50'],
            'address' => ['nullable', 'string'],
            'type' => ['required', Rule::enum(JobType::class)],
            'status' => ['required', 'boolean'],
            'expiry_date' => ['required', 'date'],
        ];

        if ($this->routeIs("jobs.update")) {
            $rules["user_id"][0] = "sometimes";
            $rules["work_type_id"][0] = "sometimes";
            $rules["work_hour_id"][0] = "sometimes";
            $rules["title"][0] = "sometimes";
            $rules["description"][0] = "sometimes";
            $rules["location"][0] = "sometimes";
            $rules["type"][0] = "sometimes";
            $rules["status"][0] = "sometimes";
            $rules["expiry_date"][0] = "sometimes";
        }

        return $rules;
    }

    public function authorize(): bool {
        return true;
    }
}
