<?php

namespace App\Http\Requests;

use App\Enums\Gender;
use App\Enums\UserRole;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class UserRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     */
    public function authorize(): bool {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\ValidationRule|array<mixed>|string>
     */
    public function rules(): array {
        $rules = [
            'name' => ["required", "string", "max:100"],
            'email' => ["required", "email", 'unique:users'],
            'mobile_no' => ["required", "string", "max:20", 'unique:users'],
            'password' => ["required", "string", "confirmed"],
            'gender' => ["required", Rule::enum(Gender::class)],
            'role' => ["sometimes", Rule::enum(UserRole::class)],
            'last_login_at' => ["nullable", "date"],
            'is_active' => ["sometimes", "boolean"],

            // file uploads
            "profile_picture" => $this->hasFile("profile_picture")
                ? ["file", "mimes:jpeg,jpg,png", "max:2048"]
                : ["nullable", "string", "max:100"],
        ];

        if ($this->method() == "PATCH" || $this->method() == "PUT") {
            $rules['name'][0] = "sometimes";
            $rules['email'] = ["sometimes", "email", Rule::unique("users")->ignore($this->user()->id)];
            $rules["mobile_no"] = [
                "sometimes", "string", "max:20", Rule::unique("users")->ignore($this->user()->id)
            ];
            $rules['password'][0] = "nullable";
            $rules["gender"][0] = "sometimes";
        }

        if ($this->routeIs("agencies.update")) {
            $rules["user_id"] = ["required", "exists:users,id"];
        }

        return $rules;
    }
}
