<?php

namespace App\Http\Requests;

use App\Enums\CookType;
use App\Enums\MaritalStatus;
use App\Enums\Religion;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class WorkerRequest extends FormRequest
{
    public function authorize(): bool {
        return true;
    }

    public function rules(): array {
        $rules = [
            'work_type_id' => ['required', 'exists:work_types,id'],
            'agency_id' => ['nullable', 'exists:agencies,id'],

            'age' => ['required', 'numeric', 'between:16,80'],
            'address' => ['required', 'string'],
            'country' => ['required', 'string', 'max:50'],
            'city' => ['required', 'string', 'max:50'],
            'pincode' => ['required', 'integer'],
            'reporting_location' => ['nullable', 'string', 'max:50'],
            'experience' => ['sometimes', 'numeric', 'between:0,29.9'],
            'credits' => ['nullable', 'integer'],
            'is_visible' => ['required', 'boolean'],

            'religion' => ['required', Rule::enum(Religion::class)],
            'marital_status' => ['required', Rule::enum(MaritalStatus::class)],
            'cook_type' => ['nullable', Rule::enum(CookType::class)],

            // file uploads
            'aadhar_front' => $this->validateFile('aadhar_front'),
            'aadhar_back' => $this->validateFile('aadhar_back'),
            'pan_card' => $this->validateFile('pan_card'),

            // worker languages
            'languages' => ['sometimes', 'array'],
            'languages.*.id' => ['required', 'exists:languages,id'],
            'languages.*.can_read' => ['required', 'boolean'],
            'languages.*.can_write' => ['required', 'boolean'],
            'languages.*.can_speak' => ['required', 'boolean'],

            // work hours of worker
            'work_hours' => ['sometimes', 'array'],
            'work_hours.*' => ['required', 'exists:work_hours,id'],

            // worker skills
            'skills' => ['sometimes', 'array'],
            'skills.*' => ['required', 'exists:skills,id']
        ];

        if ($this->routeIs("workers.update")) {
            $rules['work_type_id'][0] = 'sometimes';
            $rules['age'][0] = 'sometimes';
            $rules['address'][0] = 'sometimes';
            $rules['country'][0] = 'sometimes';
            $rules['city'][0] = 'sometimes';
            $rules['pincode'][0] = 'sometimes';
            $rules['credits'][0] = 'sometimes';
            $rules['is_visible'][0] = 'sometimes';
            $rules['religion'][0] = 'sometimes';
            $rules['marital_status'][0] = 'sometimes';
        }

        return $rules;
    }

    private function validateFile(string $field): array {
        return $this->hasFile($field)
            ? ['file', 'mimes:jpg,jpeg,png', 'max:2048']
            : ['nullable', 'string', 'max:100'];
    }
}
