<?php

namespace App\Http\Resources;

use App\Models\Job;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

/** @mixin Job */
class JobResource extends JsonResource
{
    public function toArray(Request $request): array {
        return [
            'id' => $this->id,

            'title' => $this->title,
            'description' => $this->description,
            'location' => $this->location,
            'address' => $this->address,
            'type' => $this->type,
            'status' => $this->status,
            'expiry_date' => $this->expiry_date,

            'user_id' => $this->user_id,
            'work_type_id' => $this->work_type_id,
            'work_hour_id' => $this->work_hour_id,

            // relations
            'employer' => new UserResource($this->whenLoaded('employer')),
            'work_type' => new WorkTypeResource($this->whenLoaded('workType')),
            'work_hour' => new WorkHourResource($this->whenLoaded('workHour')),
            'applicants' => UserResource::collection($this->whenLoaded('applicants')),
            'ratings' => RatingResource::collection($this->whenLoaded('ratings')),

            // timestamps
            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
        ];
    }
}
