<?php

namespace App\Http\Resources;

use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

class UserResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @return array<string, mixed>
     */
    public function toArray(Request $request): array {
        return [
            'id' => $this->id,

            'agency_id' => $this->agency_id,

            'name' => $this->name,
            'email' => $this->email,
            'mobile_no' => $this->mobile_no,
            'gender' => $this->gender,
            'role' => $this->role,
            'last_login_at' => $this->last_login_at,
            'is_active' => $this->is_active,
            'profile_picture' => $this->profile_picture,

            // relation pivot fields
            'applied_at' => $this->whenPivotLoaded('job_user', fn() => $this->pivot->applied_at),
            'application_date' => $this->whenPivotLoaded('service_user', fn() => $this->pivot->application_date),
            'status' => $this->whenPivotLoaded('service_user', fn() => $this->pivot->status),
            'is_paid' => $this->whenPivotLoaded('service_user', fn() => $this->pivot->is_paid),

            // relations
            "hirer" => new HirerResource($this->whenLoaded("hirer")),
            "worker" => new WorkerResource($this->whenLoaded("worker")),
            "agency" => new AgencyResource($this->whenLoaded("agency")),
            "jobs" => JobResource::collection($this->whenLoaded("jobs")),
            "hirings" => HiringResource::collection($this->whenLoaded("hirings")),
            "applied_jobs" => JobResource::collection($this->whenLoaded("appliedJobs")),
            "services" => ServiceResource::collection($this->whenLoaded("services")),

            // timestamps
            // 'created_at' => $this->created_at,
            // 'updated_at' => $this->updated_at
        ];
    }
}
