<?php

namespace App\Http\Resources;

use App\Models\Worker;
use Illuminate\Http\Request;
use Illuminate\Http\Resources\Json\JsonResource;

/** @mixin Worker */
class WorkerResource extends JsonResource
{
    public function toArray(Request $request): array {
        return [
            'id' => $this->id,

            'user_id' => $this->user_id,
            'work_type_id' => $this->work_type_id,
            'agency_id' => $this->agency_id,

            'age' => $this->age,
            'religion' => $this->religion,
            'experience' => $this->experience,
            'marital_status' => $this->marital_status,
            'address' => $this->address,
            'country' => $this->country,
            'city' => $this->city,
            'pincode' => $this->pincode,
            'reporting_location' => $this->reporting_location,
            'credits' => $this->credits,
            'aadhar_front' => $this->aadhar_front,
            'aadhar_back' => $this->aadhar_back,
            'pan_card' => $this->pan_card,
            'is_visible' => $this->is_visible,
            'cook_type' => $this->cook_type,

            // relations
            'user' => new UserResource($this->whenLoaded('user')),
            'work_type' => new WorkTypeResource($this->whenLoaded('workType')),
            'agency' => new AgencyResource($this->whenLoaded('agency')),
            'languages' => LanguageResource::collection($this->whenLoaded("languages")),
            'work_hours' => WorkHourResource::collection($this->whenLoaded("workHours")),
            'skills' => SkillResource::collection($this->whenLoaded("skills")),

            'created_at' => $this->created_at,
            'updated_at' => $this->updated_at,
        ];
    }
}
