<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Job extends Model
{
    use SoftDeletes, HasFactory, Filterable;

    public $filterFields = [
        "work_type_id",
        "work_hour_id",

        "title",
        "description",
        "location",
        "type",
        "status",

        // relations
        "workType",
        "workHour"
    ];
    protected $fillable = [
        'user_id',
        'work_type_id',
        'work_hour_id',

        'title',
        'description',
        'location',
        'address',
        'type',
        'status',
        'expiry_date',
    ];

    public function employer(): BelongsTo {
        return $this->belongsTo(User::class, 'user_id');
    }

    public function workType(): BelongsTo {
        return $this->belongsTo(WorkType::class);
    }

    public function workHour(): BelongsTo {
        return $this->belongsTo(WorkHour::class);
    }

    public function applicants(): BelongsToMany {
        return $this->belongsToMany(User::class, 'job_user')
            ->withPivot('applied_at');
    }

    public function ratings(): HasMany {
        return $this->hasMany(Rating::class);
    }

    protected function casts(): array {
        return [
            'status' => 'boolean',
        ];
    }
}
