<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Abbasudo\Purity\Traits\Filterable;
use Dyrynda\Database\Support\CascadeSoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;

class User extends Authenticatable
{
    use HasFactory, Notifiable, HasApiTokens, Filterable, SoftDeletes, CascadeSoftDeletes;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'agency_id',

        'name',
        'email',
        'mobile_no',
        'password',
        'gender',
        'role',
        'last_login_at',
        'is_active'
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    protected array $cascadeDeletes = ['hirer', 'worker', 'jobs'];

    public function hirer(): HasOne {
        return $this->hasOne(Hirer::class);
    }

    public function worker(): HasOne {
        return $this->hasOne(Worker::class);
    }

    public function agency(): BelongsTo {
        return $this->belongsTo(Agency::class);
    }

    public function jobs(): HasMany {
        return $this->hasMany(Job::class);
    }

    public function hirings(): HasMany {
        return $this->hasMany(Hiring::class);
    }

    public function appliedJobs(): BelongsToMany {
        return $this->belongsToMany(Job::class, "job_user")
            ->withPivot('applied_at');
    }

    public function services(): BelongsToMany {
        return $this->belongsToMany(Service::class, "service_user")
            ->withPivot(['application_date', 'status', 'is_paid']);
    }

    /**
     * Get the attributes that should be cast.
     *
     * @return array<string, string>
     */
    protected function casts(): array {
        return [
            'email_verified_at' => 'datetime',
            'password' => 'hashed'
        ];
    }
}
