<?php

namespace App\Models;

use Abbasudo\Purity\Traits\Filterable;
use Dyrynda\Database\Support\CascadeSoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\SoftDeletes;

class Worker extends Model
{
    use SoftDeletes, HasFactory, Filterable, CascadeSoftDeletes;

    protected $fillable = [
        'user_id',
        'work_type_id',
        'agency_id',

        'age',
        'experience',
        'address',
        'country',
        'city',
        'pincode',
        'reporting_location',
        'credits',
        'is_visible',
        'religion',
        'marital_status',
        'cook_type',
    ];

    protected $filterFields = [
        'agency_id',
        'work_type_id',
        'age',
        'experience',
        'country',
        'city',
        'pincode',
        'reporting_location',
        'religion',
        'marital_status',
        'cook_type',

        // relations
        'workType',
        'languages',
        'workHours',
        'skills',
    ];

    public function user(): BelongsTo {
        return $this->belongsTo(User::class);
    }

    public function workType(): BelongsTo {
        return $this->belongsTo(WorkType::class);
    }

    public function agency(): BelongsTo {
        return $this->belongsTo(Agency::class);
    }

    public function languages(): BelongsToMany {
        return $this->belongsToMany(Language::class, "language_worker")
            ->withPivot("can_read", "can_write", "can_speak");
    }

    public function workHours(): BelongsToMany {
        return $this->belongsToMany(WorkHour::class, "worker_work_hour");
    }

    public function skills(): BelongsToMany {
        return $this->belongsToMany(Skill::class, "skill_worker");
    }

    protected function casts(): array {
        return [
            'is_visible' => 'boolean'
        ];
    }
}
