<?php

use App\Enums\Gender;
use App\Enums\UserRole;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    /**
     * Run the migrations.
     */
    public function up(): void {
        Schema::create('users', function (Blueprint $table) {
            $table->id();

            $table->foreignId("agency_id")->nullable()->constrained("agencies")
                ->cascadeOnDelete();

            $table->string('name', 100);
            $table->string('email')->unique();
            $table->string("mobile_no", 20)->unique();
            $table->timestamp('email_verified_at')->nullable();
            $table->string('password');
            $table->enum("gender", array_column(Gender::cases(), "value"))
                ->default(Gender::MALE);
            $table->enum("role", array_column(UserRole::cases(), "value"))
                ->default(UserRole::WORKER);
            $table->timestamp("last_login_at")->nullable();
            $table->boolean("is_active")->default(false);

            // file uploads
            $table->string("profile_picture")->nullable();

            $table->rememberToken();
            $table->timestamps();
            $table->softDeletes();
        });

        Schema::create('password_reset_tokens', function (Blueprint $table) {
            $table->string('email')->primary();
            $table->string('token');
            $table->timestamp('created_at')->nullable();
        });

        Schema::create('sessions', function (Blueprint $table) {
            $table->string('id')->primary();
            $table->foreignId('user_id')->nullable()->index();
            $table->string('ip_address', 45)->nullable();
            $table->text('user_agent')->nullable();
            $table->longText('payload');
            $table->integer('last_activity')->index();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void {
        Schema::dropIfExists('users');
        Schema::dropIfExists('password_reset_tokens');
        Schema::dropIfExists('sessions');
    }
};
