<?php

use App\Enums\CookType;
use App\Enums\MaritalStatus;
use App\Enums\Religion;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    public function up() {
        Schema::create('workers', function (Blueprint $table) {
            $table->id();

            // foreign keys
            $table->foreignId('user_id')->constrained('users')
                ->cascadeOnDelete();
            $table->foreignId('work_type_id')->constrained('work_types')
                ->cascadeOnDelete();
            $table->foreignId('agency_id')->nullable()->constrained('agencies')
                ->cascadeOnDelete();

            $table->tinyInteger('age')->nullable();
            $table->text('address')->nullable();
            $table->string('country', 50)->nullable();
            $table->string('city', 50)->nullable();
            $table->unsignedMediumInteger('pincode');
            $table->string('reporting_location', 50)->nullable();
            $table->decimal('experience', 3, 1)->default(0);
            $table->unsignedMediumInteger('credits')->default(0);
            $table->boolean('is_visible')->default(true);

            $table->enum('religion', array_column(Religion::cases(), "value"))
                ->default(Religion::HINDU);
            $table->enum('marital_status', array_column(MaritalStatus::cases(), "value"))
                ->default(MaritalStatus::UNMARRIED);
            $table->enum('cook_type', array_column(CookType::cases(), "value"))
                ->default(CookType::NA);

            // file uploads
            $table->string('aadhar_front', 100)->nullable();
            $table->string('aadhar_back', 100)->nullable();
            $table->string('pan_card', 100)->nullable();

            $table->timestamps();
            $table->softDeletes();
        });

        Schema::create('language_worker', function (Blueprint $table) {
            $table->id();

            $table->foreignId('language_id')->constrained('languages')
                ->cascadeOnDelete();
            $table->foreignId('worker_id')->constrained('workers')
                ->cascadeOnDelete();

            $table->boolean("can_read")->default(false);
            $table->boolean("can_write")->default(false);
            $table->boolean("can_speak")->default(false);

            $table->unique(['language_id', 'worker_id']);
        });

        Schema::create('worker_work_hour', function (Blueprint $table) {
            $table->id();

            $table->foreignId('worker_id')->constrained('workers')
                ->cascadeOnDelete();
            $table->foreignId('work_hour_id')->constrained('work_hours')
                ->cascadeOnDelete();

            $table->unique(['worker_id', 'work_hour_id']);
        });

        Schema::create('skill_worker', function (Blueprint $table) {
            $table->id();

            $table->foreignId('skill_id')->constrained('skills')
                ->cascadeOnDelete();
            $table->foreignId('worker_id')->constrained('workers')
                ->cascadeOnDelete();

            $table->unique(['skill_id', 'worker_id']);
        });

        Schema::create("user_worker", function (Blueprint $table) {
            $table->id();

            $table->foreignId("user_id")->constrained("users")
                ->cascadeOnDelete();
            $table->foreignId("worker_id")->constrained("workers")
                ->cascadeOnDelete();

            $table->date("hired_date")->nullable();
            $table->boolean("is_unlocked")->default(false);
            $table->boolean("is_shortlisted")->default(false);

            $table->timestamps();
        });
    }

    public function down() {
        Schema::dropIfExists('language_worker');
        Schema::dropIfExists('worker_work_hour');
        Schema::dropIfExists('skill_worker');
        Schema::dropIfExists('workers');
    }
};
