<?php

use App\Enums\JobType;
use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration {
    public function up() {
        Schema::create('jobs', function (Blueprint $table) {
            $table->id();

            $table->foreignId('user_id')->constrained('users')
                ->cascadeOnDelete();
            $table->foreignId("work_type_id")->constrained('work_types')
                ->cascadeOnDelete();
            $table->foreignId("work_hour_id")->constrained('work_hours')
                ->cascadeOnDelete();

            $table->string('title', 100);
            $table->text('description');
            $table->string('location');
            $table->text('address')->nullable();
            $table->enum('type', array_column(JobType::cases(), "value"))
                ->default(JobType::ONSITE);
            $table->boolean('status')->default(true);
            $table->date('expiry_date');

            $table->timestamps();
            $table->softDeletes();
        });

        Schema::create('job_user', function (Blueprint $table) {
            $table->id();

            $table->foreignId("job_id")->constrained("jobs")
                ->cascadeOnDelete();
            $table->foreignId("user_id")->constrained("users")
                ->cascadeOnDelete();

            $table->dateTime("applied_at");
        });
    }

    public function down() {
        Schema::dropIfExists('job_user');
        Schema::dropIfExists('jobs');
    }
};
