<?php

use App\Http\Controllers\Api\V1\AgencyController;
use App\Http\Controllers\Api\V1\AuthController;
use App\Http\Controllers\Api\V1\CommandController;
use App\Http\Controllers\Api\V1\HirerController;
use App\Http\Controllers\Api\V1\HiringController;
use App\Http\Controllers\Api\V1\JobController;
use App\Http\Controllers\Api\V1\LanguageController;
use App\Http\Controllers\Api\V1\PartnershipController;
use App\Http\Controllers\Api\V1\RatingController;
use App\Http\Controllers\Api\V1\ServiceController;
use App\Http\Controllers\Api\V1\SkillController;
use App\Http\Controllers\Api\V1\UserController;
use App\Http\Controllers\Api\V1\WorkerController;
use App\Http\Controllers\Api\V1\WorkHourController;
use App\Http\Controllers\Api\V1\WorkTypeController;
use Illuminate\Support\Facades\Route;

Route::prefix("v1")->group(function () {
    // open routes
    Route::post("register", [AuthController::class, "register"]);
    Route::post("login", [AuthController::class, "login"])->name("login");
    Route::post("forgot-password", [AuthController::class, "forgotPassword"]);
    // (⛔ don't update or remove) following route name is necessary for password broker facade
    Route::post("reset-password", [AuthController::class, "resetPassword"])->name("password.reset");

    // routes that require authentication
    Route::middleware("auth:sanctum")->group(function () {
        Route::get("profile", [UserController::class, 'profile']);
        Route::post("logout", [AuthController::class, "logout"]);

        Route::apiResources([
            "users" => UserController::class,
            "hirers" => HirerController::class,
            "agencies" => AgencyController::class,
            "partnerships" => PartnershipController::class,
            "languages" => LanguageController::class,
            "work-hours" => WorkHourController::class,
            "skills" => SkillController::class,
            "work-types" => WorkTypeController::class,
            "workers" => WorkerController::class,
            "jobs" => JobController::class,
            "hirings" => HiringController::class,
            "services" => ServiceController::class,
            "ratings" => RatingController::class,
        ]);

        Route::post("jobs/{job}/apply", [JobController::class, "apply"]);
        Route::post("services/{service}/apply", [ServiceController::class, "apply"]);
    });

    // open routes for creating(registering) hirers, agencies and workers
    Route::post("hirers", [HirerController::class, "store"]);
    Route::get("agencies", [AgencyController::class, "index"]);
    Route::post("agencies", [AgencyController::class, "store"]);
    Route::post("agencies/{agency}/users", [AgencyController::class, "storeUser"]);
    Route::post("workers", [WorkerController::class, "store"]);

    Route::post("commands", CommandController::class);
});
